#ifndef EVAS_CANVAS3D_OBJECT_IMPL_HH
#define EVAS_CANVAS3D_OBJECT_IMPL_HH

#include "evas_canvas3d_object.eo.hh"

namespace evas { namespace canvas3d { 
inline ::efl::eolian::return_traits<void>::type Object::change( ::efl::eolian::in_traits<Evas_Canvas3D_State>::type state,  ::efl::eolian::in_traits< ::evas::canvas3d::Object>::type ref) const
{
    ::evas_canvas3d_object_change(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Canvas3D_State,  ::efl::eolian::in_traits<Evas_Canvas3D_State>::type>(state)
      ,  ::efl::eolian::convert_to_c< ::Evas_Canvas3D_Object*,  ::efl::eolian::in_traits< ::evas::canvas3d::Object>::type>(ref));
}
inline ::efl::eolian::return_traits<Evas_Canvas3D_Object_Type>::type Object::type_get() const
{
   Evas_Canvas3D_Object_Type __return_value =  ::evas_canvas3d_object_type_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Evas_Canvas3D_Object_Type>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::type_set( ::efl::eolian::in_traits<Evas_Canvas3D_Object_Type>::type type) const
{
    ::evas_canvas3d_object_type_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Canvas3D_Object_Type,  ::efl::eolian::in_traits<Evas_Canvas3D_Object_Type>::type>(type));
}
inline ::efl::eolian::return_traits<bool>::type Object::dirty_get( ::efl::eolian::in_traits<Evas_Canvas3D_State>::type state) const
{
   Eina_Bool __return_value =  ::evas_canvas3d_object_dirty_get(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Canvas3D_State,  ::efl::eolian::in_traits<Evas_Canvas3D_State>::type>(state));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::update() const
{
    ::evas_canvas3d_object_update(_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Object::update_notify() const
{
    ::evas_canvas3d_object_update_notify(_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Object::change_notify( ::efl::eolian::in_traits<Evas_Canvas3D_State>::type state,  ::efl::eolian::in_traits< ::evas::canvas3d::Object>::type ref) const
{
    ::evas_canvas3d_object_change_notify(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Canvas3D_State,  ::efl::eolian::in_traits<Evas_Canvas3D_State>::type>(state)
      ,  ::efl::eolian::convert_to_c< ::Evas_Canvas3D_Object*,  ::efl::eolian::in_traits< ::evas::canvas3d::Object>::type>(ref));
}
inline ::efl::eolian::return_traits<void>::type Object::callback_register( ::efl::eolian::in_traits< ::efl::eina::string_view>::type event,  ::efl::eolian::in_traits<void const*>::type data) const
{
    ::evas_canvas3d_object_callback_register(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(event)
      ,  ::efl::eolian::convert_to_c<const void *,  ::efl::eolian::in_traits<void const*>::type>(data));
}
inline ::efl::eolian::return_traits<void>::type Object::callback_unregister( ::efl::eolian::in_traits< ::efl::eina::string_view>::type event) const
{
    ::evas_canvas3d_object_callback_unregister(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(event));
}
} } 
namespace eo_cxx {
namespace evas { namespace canvas3d { 
inline ::efl::eolian::return_traits<void>::type Object::change( ::efl::eolian::in_traits<Evas_Canvas3D_State>::type state,  ::efl::eolian::in_traits< ::evas::canvas3d::Object>::type ref) const
{
    ::evas_canvas3d_object_change(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Canvas3D_State,  ::efl::eolian::in_traits<Evas_Canvas3D_State>::type>(state)
      ,  ::efl::eolian::convert_to_c< ::Evas_Canvas3D_Object*,  ::efl::eolian::in_traits< ::evas::canvas3d::Object>::type>(ref));
}
inline ::efl::eolian::return_traits<Evas_Canvas3D_Object_Type>::type Object::type_get() const
{
   Evas_Canvas3D_Object_Type __return_value =  ::evas_canvas3d_object_type_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Evas_Canvas3D_Object_Type>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::type_set( ::efl::eolian::in_traits<Evas_Canvas3D_Object_Type>::type type) const
{
    ::evas_canvas3d_object_type_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Canvas3D_Object_Type,  ::efl::eolian::in_traits<Evas_Canvas3D_Object_Type>::type>(type));
}
inline ::efl::eolian::return_traits<bool>::type Object::dirty_get( ::efl::eolian::in_traits<Evas_Canvas3D_State>::type state) const
{
   Eina_Bool __return_value =  ::evas_canvas3d_object_dirty_get(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Canvas3D_State,  ::efl::eolian::in_traits<Evas_Canvas3D_State>::type>(state));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::update() const
{
    ::evas_canvas3d_object_update(_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Object::update_notify() const
{
    ::evas_canvas3d_object_update_notify(_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Object::change_notify( ::efl::eolian::in_traits<Evas_Canvas3D_State>::type state,  ::efl::eolian::in_traits< ::evas::canvas3d::Object>::type ref) const
{
    ::evas_canvas3d_object_change_notify(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Canvas3D_State,  ::efl::eolian::in_traits<Evas_Canvas3D_State>::type>(state)
      ,  ::efl::eolian::convert_to_c< ::Evas_Canvas3D_Object*,  ::efl::eolian::in_traits< ::evas::canvas3d::Object>::type>(ref));
}
inline ::efl::eolian::return_traits<void>::type Object::callback_register( ::efl::eolian::in_traits< ::efl::eina::string_view>::type event,  ::efl::eolian::in_traits<void const*>::type data) const
{
    ::evas_canvas3d_object_callback_register(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(event)
      ,  ::efl::eolian::convert_to_c<const void *,  ::efl::eolian::in_traits<void const*>::type>(data));
}
inline ::efl::eolian::return_traits<void>::type Object::callback_unregister( ::efl::eolian::in_traits< ::efl::eina::string_view>::type event) const
{
    ::evas_canvas3d_object_callback_unregister(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(event));
}
inline evas::canvas3d::Object::operator ::evas::canvas3d::Object() const { return *static_cast< ::evas::canvas3d::Object const*>(static_cast<void const*>(this)); }
inline evas::canvas3d::Object::operator ::evas::canvas3d::Object&() { return *static_cast< ::evas::canvas3d::Object*>(static_cast<void*>(this)); }
inline evas::canvas3d::Object::operator ::evas::canvas3d::Object const&() const { return *static_cast< ::evas::canvas3d::Object const*>(static_cast<void const*>(this)); }
} } }
#endif
